/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import mdx from './button.mdx';

export default {
  title: 'Product Subsystem/Components/Button',
  parameters: {
    docs: {
      page: mdx,
    },
  },
  argTypes: {
    variant: {
      control: {
        type: 'select',
        options: [
          'default',
          'base',
          'brand',
          'brand-outline',
          'inverse',
          'success',
          'destructive',
          'destructive-text',
        ],
      },
      defaultValue: 'default',
    },
    size: {
      control: { type: 'select', options: ['default', 'stretch'] },
      defaultValue: 'default',
    },
    disabled: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    label: {
      control: {
        type: 'text',
      },
      defaultValue: 'Button',
    },
  },
};

const TextTemplate = (args) => `
<div ${
  args.variant === 'inverse' ? 'style="padding: 0.5rem; background: var(--sds-g-color-brand-base-20);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    ${args.label}
  </slds-button>
</div>
`;
export const Text = TextTemplate.bind({});

const TextAndIconTemplate = (args) => `
<div ${
  args.variant === 'inverse' ? 'style="padding: 0.5rem; background: var(--sds-g-color-brand-base-20);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    ${args.label}
    <slds-icon icon-name="utility:download" slot="end"></slds-icon>
  </slds-button>
</div>
`;
export const TextAndIcon = TextAndIconTemplate.bind({});

const IconTemplate = (args) => `
<div ${
  args.variant === 'inverse' ? 'style="padding: 0.5rem; background: var(--sds-g-color-brand-base-20);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    <span>↓</span>
  </slds-button>
</div>
`;
export const Icon = IconTemplate.bind({});

// Styling Hook Testing
const StylingHookStyles = (args) => `
  --slds-c-button-icon-color-foreground: ${
    args['Icon Foreground Color'] ? args['Icon Foreground Color'] : args['Foreground Color']
  };

  --slds-s-button-font-lineheight: ${args['Font Lineheight']};
  --slds-s-button-spacing-inline: ${args['Spacing Inline']};

  --slds-c-button-neutral-color-background: ${args['Background Color']};
  --slds-c-button-neutral-color-background-hover: ${args['Background Hover Color']};
  --slds-c-button-neutral-color-background-active: ${args['Background Active Color']};
  --slds-c-button-neutral-color-background-focus: ${args['Background Focus Color']};
  --slds-c-button-neutral-color-background-disabled: ${args['Background Disabled Color']};

  --slds-c-button-neutral-color-border: ${args['Border Color']};
  --slds-c-button-neutral-color-border-hover: ${args['Border Hover Color']};
  --slds-c-button-neutral-color-border-active: ${args['Border Active Color']};
  --slds-c-button-neutral-color-border-focus: ${args['Border Focus Color']};
  --slds-c-button-neutral-color-border-disabled: ${args['Border Disabled Color']};

  --slds-c-button-neutral-text-color: ${args['Text Color']};
  --slds-c-button-neutral-text-color-hover: ${args['Text Hover Color']};
  --slds-c-button-neutral-text-color-focus: ${args['Text Focus Color']};
  --slds-c-button-neutral-text-color-active: ${args['Text Active Color']};
  --slds-c-button-neutral-text-color-disabled: ${args['Text Disabled Color']};

  --slds-c-button-neutral-shadow: 0 0 3px ${args['Shadow Color']};
  --slds-c-button-neutral-shadow-focus: 0 0 3px ${args['Shadow Focus Color']};

  --slds-c-button-brand-color-background: ${args['Brand Background Color']};
  --slds-c-button-brand-color-background-hover: ${args['Brand Background Hover Color']};
  --slds-c-button-brand-color-background-focus: ${args['Brand Background Focus Color']};
  --slds-c-button-brand-color-background-active: ${args['Brand Background Active Color']};

  --slds-c-button-brand-color-border: ${args['Brand Border Color']};
  --slds-c-button-brand-color-border-hover: ${args['Brand Border Hover Color']};
  --slds-c-button-brand-color-border-active: ${args['Brand Border Active Color']};
  --slds-c-button-brand-color-border-focus: ${args['Brand Border Focus Color']};

  --slds-c-button-brand-text-color: ${args['Brand Text Color']};
  --slds-c-button-brand-text-color-hover: ${args['Brand Text Hover Color']};
  --slds-c-button-brand-text-color-active: ${args['Brand Text Active Color']};
  --slds-c-button-brand-text-color-focus: ${args['Brand Text Focus Color']};

  ${args.variant === 'inverse' ? 'padding: 0.5rem; background: var(--sds-g-color-brand-base-20);' : ''}
`;

const StylingHookTemplate = (args) => `
  <div style="${StylingHookStyles(args)}"}">
    <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
      ${args.label}
      <slds-icon icon-name="utility:download" slot="end"></slds-icon>
    </slds-button>
  </div>
`;

export const StylingHooks = StylingHookTemplate.bind({});

StylingHooks.argTypes = {
  'Font Lineheight': {
    control: {
      type: 'text',
    },
    defaultValue: '1.875rem',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Spacing Inline': {
    control: {
      type: 'text',
    },
    defaultValue: '1rem',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Background Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#fff',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Background Hover Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#FFFACD',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Background Active Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#FFEFD5',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Background Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#F0E68C',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Background Disabled Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#e5e5e5',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Border Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'orange',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Border Hover Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#FF4500',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Border Active Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#B22222',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Border Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#8B008B',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Border Disabled Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#939393',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Text Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#9ACD32',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Text Hover Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#3CB371',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Text Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#8B008B',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Text Active Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#6B8E23',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Text Disabled Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#939393',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Shadow Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#3CB371',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Shadow Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'navy',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Default Variant',
    },
  },
  'Brand Background Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'salmon',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Background Hover Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#FFA07A',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Background Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#FFEFD5',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Background Active Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'tomato',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Border Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'thistle',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Border Hover Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'violet',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Border Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#008B8B',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Border Active Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#9932CC',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Text Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'white',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Text Hover Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#00008B',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Text Active Color': {
    control: {
      type: 'color',
    },
    defaultValue: 'chocolate',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
  'Brand Text Focus Color': {
    control: {
      type: 'color',
    },
    defaultValue: '#6495ED',
    table: {
      category: 'Styling Hooks',
      subcategory: 'Brand Variant',
    },
  },
};
